@@ -141,5 +141,7 @@ par(bg="cornsilk")
 data(quakes)
 coplot(long ~ lat | depth, data=quakes, pch=21, bg="green3")
 
-par(opar)
+## --- "math annotation" in plots :
+example(plotmath)
 
+par(opar)
