@@ -1,6 +1,8 @@
 /*
  *  R : A Computer Langage for Statistical Data Analysis
  *  Copyright (C) 1996  Robert Gentleman and Ross Ihaka
+ *  Copyright (C) 1999-2000   Robert Gentleman, Ross Ihaka and the
+ *                            R Development Core Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,11 +20,11 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <Rconfig.h>
+#include <config.h>
 #endif
 
-#include "Mathlib.h"
-#include "Applic.h"
+#include "Mathlib.h" /* fmax2, imin2, imax2, fsquare, fcube */
+#include "Applic.h"  /* prototypes for lowess and clowess */
 
 static void sort(double *x, int n)
 {
@@ -148,6 +150,7 @@ static void lowest(double *x, double *y, int n, double *xs, double *ys,
     }
 }
 
+static
 void clowess(double *x, double *y, int n,
 	     double f, int nsteps, double delta,
 	     double *ys, double *rw, double *res)
