@@ -81,8 +81,7 @@ static void   GNOME_Polyline(int, double*, double*, int, DevDesc*);
 static void   GNOME_Rect(double, double, double, double, int, int, int, DevDesc*);
 static void   GNOME_Resize(DevDesc*);
 static double GNOME_StrWidth(char*, DevDesc*);
-static void   GNOME_Text(double, double, int, char*, double, double, double,
-		       DevDesc*);
+static void   GNOME_Text(double, double, int, char*, double, DevDesc*);
 static void   GNOME_MetricInfo(int, double*, double*, double*, DevDesc*);
 
 			/* Pixel Dimensions (Inches) */
@@ -144,8 +143,8 @@ static void SetLineType(GdkBitmap *stipple, int newlty, int newlwd)
     dashlist[i] = j;
     newlty = newlty >> 4;
   }
-
-  /* set dashes */
+  */
+  /*  set dashes */
   /*  gdk_gc_set_dashes(gc, 0, dashlist, i);*/
 }
 
@@ -298,13 +297,10 @@ static double GNOME_StrWidth(char *str, DevDesc *dd)
 
 static void GNOME_MetricInfo(int c, double *ascent, double *descent, double *width, DevDesc *dd)
 {
-#ifdef BUG61
-#else
     /* metric information not available => return 0,0,0 */
     *ascent = 0.0;
     *descent = 0.0;
     *width = 0.0;
-#endif
 }
 
 static void GNOME_Clip(double x0, double x1, double y0, double y1, DevDesc *dd)
@@ -388,7 +384,7 @@ static void GNOME_Activate(DevDesc *dd)
 
   devnum = deviceNumber(dd);
   devnum++;
-  numdigits = floor(Log10(devnum)) + 1;
+  numdigits = floor(R_Log10(devnum)) + 1;
   title_text = g_malloc(text_len + numdigits + 1);
 
   g_return_if_fail(title_text != NULL);
@@ -416,7 +412,7 @@ static void GNOME_Deactivate(DevDesc *dd)
 
   devnum = deviceNumber(dd);
   devnum++;
-  numdigits = floor(Log10(devnum)) + 1;
+  numdigits = floor(R_Log10(devnum)) + 1;
   title_text = g_malloc(text_len + numdigits + 1);
 
   g_return_if_fail(title_text != NULL);
@@ -634,7 +630,7 @@ static void GNOME_Polygon(int n, double *x, double *y, int coords,
 }
 
 static void GNOME_Text(double x, double y, int coords,
-		       char *str, double xc, double yc, double rot, DevDesc *dd)
+		       char *str, double rot, DevDesc *dd)
 {
   GnomeCanvasItem *item;
   gnomeDesc *gtkd = (gnomeDesc *) dd->deviceSpecific;
