@@ -222,6 +222,7 @@ double atanh(double);
 #define gamma(x) gammafn(x)
 #define lgamma(x) lgammafn(x)
 
-
+/* 27/03/2000 win32-api needs this */
+#define NONAMELESSUNION
 
 #endif
