@@ -113,7 +113,8 @@ lqs.default <-
 	     as.integer(quantile), as.integer(lts), as.integer(adj),
 	     as.integer(samp), as.integer(ps), as.integer(nsamp),
 	     crit=double(1), sing=integer(1), bestone=integer(ps),
-	     coefficients=double(p), as.integer(k0), as.double(beta)
+	     coefficients=double(p), as.integer(k0), as.double(beta),
+             PACKAGE="lqs"
 	     )[c("crit", "sing", "coefficients", "bestone")]
     z$sing <- paste(z$sing, "singular samples of size", ps, "out of", nsamp)
     z$bestone <- sort(z$bestone)
@@ -153,7 +154,7 @@ lqs.default <-
     z
 }
 
-print.lqs <- function (x, digits = max(3, .Options$digits - 3), ...)
+print.lqs <- function (x, digits = max(3, getOption("digits") - 3), ...)
 {
     if(!is.null(cl <- x$call)) {
 	cat("Call:\n")
@@ -217,7 +218,8 @@ cov.rob <- function(x, cor = FALSE, quantile.used = floor((n+p+1)/2),
 		 as.double(x), as.integer(n), as.integer(p),
 		 as.integer(qn), as.integer(method=="mcd"),
 		 as.integer(samp), as.integer(ps), as.integer(nsamp),
-		 crit=double(1), sing=integer(1), bestone=integer(n)
+		 crit=double(1), sing=integer(1), bestone=integer(n),
+                 PACKAGE="lqs"
 		 )
 	z$sing <- paste(z$sing, "singular samples of size", ps, "out of", nsamp)
 	crit <- z$crit + 2*sum(log(divisor)) +
