@@ -2,6 +2,9 @@ SEXP do_math1(SEXP, SEXP, SEXP, SEXP);
 SEXP do_math2(SEXP, SEXP, SEXP, SEXP);
 SEXP do_math3(SEXP, SEXP, SEXP, SEXP);
 SEXP do_math4(SEXP, SEXP, SEXP, SEXP);
+#ifdef WHEN_MATH5_IS_THERE
+ SEXP do_math5(SEXP, SEXP, SEXP, SEXP);
+#endif
 SEXP do_cmathfuns(SEXP, SEXP, SEXP, SEXP);
 
 SEXP complex_math1(SEXP, SEXP, SEXP, SEXP);
