@@ -463,15 +463,11 @@ SEXP do_matprod(SEXP call, SEXP op, SEXP args, SEXP rho)
 	nrx = 0;
 	ncx = 0;
 	if (PRIMVAL(op) == 0) {
-	    if (LENGTH(x) == nry) {
+	    if (LENGTH(x) == nry) { /* x as row vector */
 		nrx = 1;
 		ncx = LENGTH(x);
 	    }
-	    else if (LENGTH(x) == ncy) {
-		ncx=1;
-		nrx=LENGTH(x);
-	    }
-	    if (nry * ncy == 1) {
+	    else if (nry == 1) { /* x as col vector */
 		nrx = LENGTH(x);
 		ncx = 1;
 	    }
@@ -489,17 +485,13 @@ SEXP do_matprod(SEXP call, SEXP op, SEXP args, SEXP rho)
 	nry = 0;
 	ncy = 0;
 	if (PRIMVAL(op) == 0) {
-	    if (LENGTH(y) == ncx) {
+	    if (LENGTH(y) == ncx) { /* y as col vector */
 		nry = LENGTH(y);
 		ncy = 1;
 	    }
-	    else if (LENGTH(y) == nrx){
-		ncy = LENGTH(y);
+	    else if (ncx == 1){ /* y as row vector */
 		nry = 1;
-	    }
-	    if (nrx * ncx == 1) {
 		ncy = LENGTH(y);
-		nry = 1;
 	    }
 	}
 	else {
@@ -547,16 +539,25 @@ SEXP do_matprod(SEXP call, SEXP op, SEXP args, SEXP rho)
 	    PROTECT(dimnames = allocVector(VECSXP, 2));
 	    PROTECT(dimnamesnames = allocVector(STRSXP, 2));
 	    if (xdims != R_NilValue) {
-		dn = getAttrib(xdims, R_NamesSymbol);
-		VECTOR(dimnames)[0] = VECTOR(xdims)[0];
-		if(!isNull(dn))
-		    STRING(dimnamesnames)[0] = STRING(dn)[0];
+		if (ldx == 2 || ncx ==1) {
+		    dn = getAttrib(xdims, R_NamesSymbol);
+		    VECTOR(dimnames)[0] = VECTOR(xdims)[0];
+		    if(!isNull(dn))
+			STRING(dimnamesnames)[0] = STRING(dn)[0];
+		}
 	    }
 	    if (ydims != R_NilValue) {
-		dn = getAttrib(ydims, R_NamesSymbol);
-		VECTOR(dimnames)[1] = VECTOR(ydims)[1];
-		if(!isNull(dn))
-		    STRING(dimnamesnames)[1] = STRING(dn)[1];
+		if (ldy == 2 ){
+		    dn = getAttrib(ydims, R_NamesSymbol);
+		    VECTOR(dimnames)[1] = VECTOR(ydims)[1];
+		    if(!isNull(dn))
+			STRING(dimnamesnames)[1] = STRING(dn)[1];
+		} else if (nry == 1) {
+		    dn = getAttrib(ydims, R_NamesSymbol);
+		    VECTOR(dimnames)[1] = VECTOR(ydims)[0];
+		    if(!isNull(dn))
+			STRING(dimnamesnames)[1] = STRING(dn)[0];
+		}
 	    }
 	    setAttrib(dimnames, R_NamesSymbol, dimnamesnames);
 	    setAttrib(ans, R_DimNamesSymbol, dimnames);
