@@ -1,6 +1,7 @@
 /*
  *  R : A Computer Language for Statistical Data Analysis
  *  Copyright (C) 1995-1997, 1998  Robert Gentleman and Ross Ihaka
+ *  Copyright (C) 1998-2000  the R Development Core Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,7 +28,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <Rconfig.h>
+#include <config.h>
 #endif
 
 #include "Print.h"
@@ -122,7 +123,7 @@ void printRealVector(double *x, int n, int index)
     Rprintf("\n");
 }
 
-void printComplexVector(complex *x, int n, int index)
+void printComplexVector(Rcomplex *x, int n, int index)
 {
     int i, w, wr, dr, er, wi, di, ei, labwidth=0, width;
 
@@ -315,7 +316,7 @@ static void printNamedRealVector(double * x, int n, SEXP * names)
     Rprintf("\n");
 }
 
-static void printNamedComplexVector(complex *x, int n, SEXP *names)
+static void printNamedComplexVector(Rcomplex *x, int n, SEXP *names)
 {
     int i, j, k, w, wn, wr, dr, er, wi, di, ei, nlines, nperline;
 
