@@ -23,6 +23,7 @@
  */
 
 #include "Mathlib.h"
+#include "dpq.h"
 
 double dpois(double x, double lambda, int give_log)
 {
@@ -35,11 +36,15 @@ double dpois(double x, double lambda, int give_log)
 	warning("non-integer x = %f", x);
 	return R_D__0;
     }
-    if(lambda <= 0.0) ML_ERR_return_NAN;
+    if(lambda < 0.0) ML_ERR_return_NAN;
 
     if (x < 0)
 	return R_D__0;
     if(!R_FINITE(x))
 	return R_D__0;
+
+    if (lambda == 0.0)
+	    return (x > 0) ? R_D__0 : R_D__1 ;
+
     return R_D_exp(x * log(lambda) - lambda - lgammafn(x + 1));
 }
