@@ -1,6 +1,7 @@
 /*
  *  Mathlib : A C Library of Special Functions
  *  Copyright (C) 1998 Ross Ihaka
+ *  Copyright (C) 2000 The R Development Core Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
  *
  *  SYNOPSIS
  *
@@ -39,7 +40,7 @@
 
 double lgammacor(double x)
 {
-    static double algmcs[15] = {
+    static /* const */ double algmcs[15] = {
 	+.1666389480451863247205729650822e+0,
 	-.1384948176067563840732986059135e-4,
 	+.9810825646924729426157171547487e-8,
@@ -56,22 +57,23 @@ double lgammacor(double x)
 	-.3401102254316748799999999999999e-29,
 	+.1276642195630062933333333333333e-30
     };
-    static int nalgm = 0;
-    static double xbig = 0;
-    static double xmax = 0;
+
     double tmp;
 
-    if (nalgm == 0) {/* initialize machine dependent constants _ONCE_ */
-	nalgm = chebyshev_init(algmcs, 15, d1mach(3));
-	xbig = 1 / sqrt(d1mach(3)); /* ~ 94906265.6 for IEEE double */
-	xmax = exp(fmin2(log(d1mach(2) / 12), -log(12 * d1mach(1))));
-		/* ~= 3.745 e306 for IEEE double */
-    }
+    static int nalgm = 0;
+    static double xbig = 0, xmax = 0;
 
-    if (x < 10) {
-	ML_ERROR(ME_DOMAIN);
-	return ML_NAN;
+    /* Initialize machine dependent constants, the first time gamma() is called.
+	FIXME for threads ! */
+    if (nalgm == 0) {
+	/* For IEEE double precision : nalgm = 5 */
+	nalgm = chebyshev_init(algmcs, 15, DBL_EPSILON/2);/*was d1mach(3)*/
+	xbig = 1 / sqrt(DBL_EPSILON/2); /* ~ 94906265.6 for IEEE double */
+	xmax = exp(fmin2(log(DBL_MAX / 12), -log(12 * DBL_MIN)));
+	/*   = DBL_MAX / 48 ~= 3.745e306 for IEEE double */
     }
+    if (x < 10)
+	ML_ERR_return_NAN
     else if (x >= xmax) {
 	ML_ERROR(ME_UNDERFLOW);
 	return ML_UNDERFLOW;
