@@ -23,6 +23,7 @@
  */
 
 #include "Mathlib.h"
+#include "dpq.h"
 
 double ppois(double x, double lambda, int lower_tail, int log_p)
 {
@@ -30,11 +31,14 @@ double ppois(double x, double lambda, int lower_tail, int log_p)
     if (ISNAN(x) || ISNAN(lambda))
 	return x + lambda;
 #endif
-    if(lambda <= 0.0) ML_ERR_return_NAN;
+    if(lambda < 0.0) ML_ERR_return_NAN;
 
     x = floor(x + 1e-7);
     if (x < 0)
 	return R_DT_0;
+
+    if ( lambda == 0.0 )
+	return R_DT_1;
     if (!R_FINITE(x))
 	return R_DT_1;
 
