@@ -61,28 +61,34 @@ double qbinom(double p, double n, double pr, int lower_tail, int log_p)
     gamma = (q - pr) / sigma;
 
 #ifdef DEBUG_qbinom
-    REprintf("qbinom(p=%7g, n=%7g, pr=%7g, l.t.=%2d, log=%2d): "
-	     "sigm=%7g, gam=%5g\n",
+    REprintf("qbinom(p=%7g, n=%g, pr=%7g, l.t.=%d, log=%d): sigm=%g, gam=%g\n",
 	     p,n,pr, lower_tail, log_p, sigma, gamma);
 #endif
-    /* FIXME: This is far from optimal :
-       -- "same" code in qpois.c, qbinom.c, qnbinom.c */
-    if(!lower_tail || log_p)
-	p = R_DT_qIv(p);
+    /* Note : "same" code in qpois.c, qbinom.c, qnbinom.c --
+     * FIXME: This is far from optimal [cancellation for p ~= 1, etc]: */
+    if(!lower_tail || log_p) {
+	p = R_DT_qIv(p); /* need check again (cancellation!): */
+	if (p == 0.) return 0.;
+	if (p == 1.) return n;
+    }
+    /* temporary hack --- FIXME --- */
+    if (p + 1.01*DBL_EPSILON >= 1.) return n;
 
+    /* y := approx.value (Cornish-Fisher expansion) :  */
     z = qnorm(p, 0., 1., /*lower_tail*/LTRUE, /*log_p*/LFALSE);
     y = floor(mu + sigma * (z + gamma * (z*z - 1) / 6) + 0.5);
+    if(y > n) /* way off */ y = n;
 
 #ifdef DEBUG_qbinom
-    REprintf("  new p=%7g, z=%7g, y=%5g\n", p, z, y);
+    REprintf("  new (p,1-p)=(%7g,%7g), z=qnorm(..)=%7g, y=%5g\n", p, 1-p, z, y);
 #endif
     z = pbinom(y, n, pr, /*lower_tail*/LTRUE, /*log_p*/LFALSE);
 
     /* fuzz to ensure left continuity: */
     p *= 1 - 64*DBL_EPSILON;
-#ifdef DEBUG_qbinom
-    REprintf("\tnew z=%7g >=? p = %7g\n", z,p);
-#endif
+
+/*-- Fixme, here y can be way off --
+  should use interval search instead of primitive stepping down or up */
 
 #ifdef maybe_future
     if((lower_tail && z >= p) || (!lower_tail && z <= p)) {
@@ -90,6 +96,9 @@ double qbinom(double p, double n, double pr, int lower_tail, int log_p)
     if(z >= p) {
 #endif
 			/* search to the left */
+#ifdef DEBUG_qbinom
+	REprintf("\tnew z=%7g >= p = %7g  --> search to left (y--) ..\n", z,p);
+#endif
 	for(;;) {
 	    if(y == 0 ||
 	       (z = pbinom(y - 1, n, pr, /*l._t.*/LTRUE, /*log_p*/LFALSE)) < p)
@@ -98,7 +107,9 @@ double qbinom(double p, double n, double pr, int lower_tail, int log_p)
 	}
     }
     else {		/* search to the right */
-
+#ifdef DEBUG_qbinom
+	REprintf("\tnew z=%7g < p = %7g  --> search to right (y++) ..\n", z,p);
+#endif
 	for(;;) {
 	    y = y + 1;
 	    if(y == n ||
