@@ -1,6 +1,7 @@
 /*
  *  Mathlib : A C Library of Special Functions
  *  Copyright (C) 1998 Ross Ihaka
+ *  Copyright (C) 2000 The R Development Core Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
  *
  *  SYNOPSIS
  *
@@ -30,13 +31,8 @@
 
 double rcauchy(double location, double scale)
 {
-    if (
-#ifdef IEEE_754
-	!finite(location) || !finite(scale) ||
-#endif
-	scale < 0) {
-	ML_ERROR(ME_DOMAIN);
-	return ML_NAN;
-    }
-    return location + scale * tan(M_PI * sunif());
+    if (!R_FINITE(location) || !R_FINITE(scale) || scale < 0)	
+	ML_ERR_return_NAN;
+
+    return location + scale * tan(M_PI * unif_rand());
 }
