@@ -1,6 +1,7 @@
 /*
  *  Mathlib : A C Library of Special Functions
  *  Copyright (C) 1998 Ross Ihaka
+ *  Copyright (C) 2000 The R Development Core Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,7 +32,7 @@
  *
  *  REFERENCE
  *
- *    Devroye, L. (1980).
+ *    Devroye, L. (1986).
  *    Non-Uniform Random Variate Generation.
  *    New York:Springer-Verlag. Page 480.
  *
@@ -45,13 +46,8 @@
 
 double rnbinom(double n, double p)
 {
-    if(
-#ifdef IEEE_754
-	!R_FINITE(n) || !R_FINITE(p) ||
-#endif
-	n <= 0 || p <= 0 || p >= 1) {
-	ML_ERROR(ME_DOMAIN);
-	return ML_NAN;
-    }
+    if(!R_FINITE(n) || !R_FINITE(p) || n <= 0 || p <= 0 || p >= 1)
+	ML_ERR_return_NAN;
+
     return rpois(rgamma(n, (1 - p) / p));
 }
